Enum blaze_rs::core::device::AtomicScope
source · #[non_exhaustive]#[repr(u64)]pub enum AtomicScope {
WorkGroup,
Device,
AllDevices,
}Available on crate feature
cl3 only.Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
WorkGroup
Support for memory ordering constraints that apply to all work-items in a work-group.
Device
Support for memory ordering constraints that apply to all work-items executing on the device.
AllDevices
Support for memory ordering constraints that apply to all work-items executing across all devices that can share SVM memory with each other and the host process.