Struct blaze_rs::core::RawPipe

source ·
#[repr(transparent)]
pub struct RawPipe(_);
Available on crate feature cl2 only.

Implementations

source

impl RawPipe

source

pub fn new( access: MemAccess, host_access: bool, packet_size: u32, max_packets: u32 ) -> Result<Self>

source

pub fn new_in( ctx: &RawContext, access: MemAccess, host_access: bool, packet_size: u32, max_packets: u32 ) -> Result<Self>

source

pub fn packet_size(&self) -> Result<NonZeroU32>

Return pipe packet size specified when pipe is created.

source

pub fn max_packets(&self) -> Result<NonZeroU32>

Return max. number of packets specified when pipe is created.

Methods from Deref<Target = RawMemObject>

source

pub unsafe fn retain(&self) -> Result<()>

source

pub fn id(&self) -> cl_mem

source

pub fn id_ref(&self) -> &cl_mem

source

pub fn id_ref_mut(&mut self) -> &mut cl_mem

source

pub fn ty(&self) -> Result<MemObjectType>

Returns the memory obejct’s type

source

pub fn associated_memobject(&self) -> Result<Option<RawMemObject>>

Available on crate feature cl1_1 only.

Return memory object from which memobj is created.

source

pub fn flags(&self) -> Result<MemFlags>

Return the flags argument value specified when memobj is created.

source

pub fn size(&self) -> Result<usize>

Return actual size of the data store associated with memobj in bytes.

source

pub fn host_ptr(&self) -> Result<Option<NonNull<c_void>>>

If memobj is created with a host_ptr specified, return the host_ptr argument value specified when memobj is created.

source

pub fn map_count(&self) -> Result<u32>

Map count. The map count returned should be considered immediately stale. It is unsuitable for general use in applications. This feature is provided for debugging.

source

pub fn reference_count(&self) -> Result<u32>

Return memobj reference count. The reference count returned should be considered immediately stale. It is unsuitable for general use in applications. This feature is provided for identifying memory leaks.

source

pub fn context(&self) -> Result<RawContext>

Return context specified when memory object is created.

source

pub fn offset(&self) -> Result<usize>

Available on crate feature cl1_1 only.

Return offset if memobj is a sub-buffer object created using create_sub_buffer. Returns 0 if memobj is not a subbuffer object.

source

pub fn uses_svm_pointer(&self) -> Result<bool>

Return true if memobj is a buffer object that was created with CL_MEM_USE_HOST_PTR or is a sub-buffer object of a buffer object that was created with CL_MEM_USE_HOST_PTR and the host_ptr specified when the buffer object was created is a SVM pointer; otherwise returns false.

source

pub fn on_destruct(&self, f: impl 'static + FnOnce() + Send) -> Result<()>

Available on crate feature cl1_1 only.

Adds a callback to be executed when the memory object is destructed by OpenCL.

source

pub fn on_destruct_boxed(&self, f: Box<dyn FnOnce() + Send>) -> Result<()>

Available on crate feature cl1_1 only.
source

pub unsafe fn on_destruct_raw( &self, f: unsafe extern "C" fn(memobj: cl_mem, user_data: *mut c_void), user_data: *mut c_void ) -> Result<()>

Available on crate feature cl1_1 only.